@@ -1,11 +1,9 @@
+#include "RedatamDatabase.hpp"
+#include <cpp11/function.hpp>
+
 #include <string>
 
-#include <cpp11/function.hpp> // cpp11::stop
-
-#include "redatamlib/entities/RedatamDatabase.hpp"
-
 using namespace cpp11;
-using std::string;
 
 [[cpp11::register]] cpp11::list
 export_redatam_to_list_(std::string dicFilePath) {
@@ -13,6 +11,7 @@ export_redatam_to_list_(std::string dicFilePath) {
     RedatamLib::RedatamDatabase db(dicFilePath);
     return db.ExportRLists();
   } catch (const std::exception &e) {
-    cpp11::stop("Export failed: %s", e.what());
+    std::string errorMsg = "Error: " + std::string(e.what());
+    cpp11::stop(errorMsg.c_str());
   }
 }
