@@ -2,7 +2,7 @@
 #define REDATAMLIB_BITARRREADER_HPP
 
 #include <bitset>
-#include <cstdint>  // uint16_t, uint32_t
+#include <cstdint> // uint16_t, uint32_t
 #include <vector>
 
 namespace RedatamLib {
@@ -10,8 +10,8 @@ using std::bitset;
 using std::vector;
 
 class BitArrayReader {
- public:
-  BitArrayReader(size_t dataSize);
+public:
+  explicit BitArrayReader(size_t dataSize);
   ~BitArrayReader() = default;
 
   BitArrayReader(const BitArrayReader &) = delete;
@@ -19,7 +19,7 @@ class BitArrayReader {
 
   void ParseBits(vector<uint32_t> *results, uint32_t data);
 
- private:
+private:
   size_t m_varSize;
   size_t m_remainderSize;
   bitset<32> m_mask;
@@ -29,6 +29,6 @@ class BitArrayReader {
   bitset<32> CreateMask(size_t size);
 };
 
-}  // namespace RedatamLib
+} // namespace RedatamLib
 
-#endif  // REDATAMLIB_BITARRREADER_HPP
+#endif // REDATAMLIB_BITARRREADER_HPP
